
***********************************************************************************************************************************************
Intangible investments, scaling, and the trend in the accrual-cash flow association
Jeremiah Green, Henock Louis, and Jalal Sani

This SAS code downloads raw data from WRDS and generates the final dataset used in the analysis presented in the paper and the online appendix.          																   ***
***********************************************************************************************************************************************



* Libraries for saving data and output;
%let FiguresAddress =..\Data\Fig;
libname data "..\Data"; run;
libname comp "..\Data\Comp"; run;
libname crsp "..\Data\CRSP"; run;
libname ff "..\Data\Fama_French"; run;
* Fama-French Industry classification and winsorizing macros;
%include "macros\winsor.sas";
%include "macros\ind_ff48.sas";


*==================================================================;
* Download data from WRDS;
*===================================================================;
%let wrds=wrds.wharton.upenn.edu 4016;options comamid=TCP remote=WRDS;
signon username=_prompt_; 

rsubmit; /*Data were downloaded on May 1, 2021*/
proc download data=comp.company out=comp.company; run;
proc download data=comp.funda out=comp.funda; run;
proc download data=crsp.ccmxpf_linktable out=crsp.ccmxpf_linktable; run;
endrsubmit;


rsubmit; /*Data were downloaded on May 28, 2021*/
proc download data=crsp.msf  out=crsp.msf; run;
proc download data=crsp.msedelist out=crsp.msedelist; run;
proc download data=ff.factors_monthly out=ff.factors_monthly; run;
endrsubmit;


*==================================================================;
* Compustat data;
*===================================================================;
proc sql;
create table comp
	as select c.gvkey, datadate, sic, fyear, oancf, at, act, che, lct, ibc, dlc, 
	abs(prcc_f) as prcc, abs(prcc_f)*csho as mve, dp, ceq, xsga, sale, xad, 
	lt, xrd, capx, txdc, esubc, sppiv, fopo, OIADP, SPI, ib, pi 
	from comp.company as c, comp.funda as f
	where f.gvkey = c.gvkey
    and f.indfmt='INDL' and f.datafmt='STD' and f.popsrc='D' and f.consol='C';  
	quit; 

proc sort data=comp nodupkey; 
	by gvkey fyear; 
	run;

/*Drop financial firms & Set missing R&D, advertising, and SG&A equal to zero*/
data comp2; 
	set comp; 
	if missing(xad)  then  ad=0; else  ad=xad;
	if missing(xrd)  then  rd=0; else  rd=xrd;	
	if missing(xsga) then sga=0; else sga=xsga;	
	if 6000<=SIC<=6999 then delete;
	run; 

/*Lagged variables*/
proc sql;
	create table comp3 as
	select a.*
	, b.act as lag_act, b.che as lag_che, b.lct as lag_lct, b.dlc as lag_dlc, b.sale as lag_sale
	, b.at as lag_at, b.mve as lag_mve, b.prcc as lag_prcc, b.ceq as lag_ceq
	from comp2 a left join comp2 b
	on a.gvkey=b.gvkey and a.fyear-1=b.fyear;
	quit;

data comp4; 
	set comp3;
	ave_at 		  =(at  + lag_at  )/2;
	ave_mve		  =(mve + lag_mve )/2;
	ave_ceq       =(ceq + lag_ceq )/2;
	ave_prcc 	  =(prcc+ lag_prcc)/2;

	ch_act=act-lag_act;
	ch_che=che-lag_che; 
	ch_lct=lct-lag_lct; 
	ch_dlc=dlc-lag_dlc;

	if fyear<1988 then acc = (ch_act-ch_che) - (ch_lct-ch_dlc) - dp;
	else acc=ibc-oancf;      

	if fyear<1988 then cfo=ib-acc;
	else cfo=oancf;

	if not missing(acc) and not missing(cfo);
	if ave_at<10 then delete;
	if ave_mve<10 then delete;
	if ave_ceq<10 then delete;
	if ave_prcc<1 then delete;
	run;

/*Alternative intangible investment (investment SG&A) measure following Enache and Srivastava [2018]*/
%ind_ff48 (dset=comp4, outp=invest_sga, sic=sic, bin_var=ff_, ind_code=ff_ind);

data invest_sga2; 
	set invest_sga; 
	main_sga=sum(sga,-rd,-ad);
	main_sga_ave_at=main_sga/ave_at;
	sale_ave_at=sale/ave_at;
	ch_sale=sale-lag_sale;

	if ch_sale<0 then decrease_sale=1; else decrease_sale=0;
	if ib<0 then loss=1; else loss=0;

	if missing(main_sga) then delete;
	if missing(ch_sale) then delete;
	if missing(ib) then delete;
	run; 

proc sort data=invest_sga2; 
	by fyear ff_ind; 
	run;

%winsor(dsetin=invest_sga2, dsetout=invest_sga2, byvar=fyear, vars= main_sga_ave_at sale_ave_at, type=winsor, pctl=1 99);

/*Estimate coefficients used to measure intangible investment (investment SG&A) measure for each industry and year*/
proc reg data=invest_sga2 outest=invest_sga_coeff edf noprint; 
	by fyear ff_ind; 
	model main_sga_ave_at = sale_ave_at decrease_sale loss; 
	run;

/*Alternative intangible investment measure (inv_sga)*/
proc sql;
	create table invest_sga3 (keep=gvkey fyear inv_sga) 
	as select a.*, (a.main_sga_ave_at-b.sale_ave_at*a.sale_ave_at)*a.ave_at as inv_sga
	from invest_sga2 a left join invest_sga_coeff (where =(_EDF_>6)) b
	on a.ff_ind=b.ff_ind and a.fyear=b.fyear;
	quit;

/*Add alternative intangible investment measure (inv_sga)*/
proc sql;
	create table comp6 
	as select a.*, b.inv_sga
	from comp4 a left join invest_sga3 b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
	quit;

proc datasets nowarn nolist nodetails;
     delete comp comp2-comp5 Xtemp Xtemp_pctl invest_sga invest_sga2 invest_sga3 Invest_sga_coeff;
	 run; quit;

/*Lagged R&D, advertising, and Investment SG&A*/
proc sql; create table comp7 
	as select a.*
	, b1.rd  as rd_lag1     , b1.ad  as ad_lag1    , b1.inv_sga  as inv_sga_lag1   
	, b2.rd  as rd_lag2     , b2.ad  as ad_lag2    , b2.inv_sga  as inv_sga_lag2
	, b3.rd  as rd_lag3     , b3.ad  as ad_lag3    , b3.inv_sga  as inv_sga_lag3
	, b4.rd  as rd_lag4     , b4.ad  as ad_lag4    , b4.inv_sga  as inv_sga_lag4
	, b5.rd  as rd_lag5     , b5.ad  as ad_lag5    , b5.inv_sga  as inv_sga_lag5
	, b6.rd  as rd_lag6      
	, b7.rd  as rd_lag7       
	, b8.rd  as rd_lag8       
	, b9.rd  as rd_lag9       
	, b10.rd as rd_lag10     
	from comp6 a 
	left join comp6 b1   on a.gvkey=b1.gvkey   and a.fyear-1 =b1.fyear
	left join comp6 b2   on a.gvkey=b2.gvkey   and a.fyear-2 =b2.fyear
	left join comp6 b3   on a.gvkey=b3.gvkey   and a.fyear-3 =b3.fyear
	left join comp6 b4   on a.gvkey=b4.gvkey   and a.fyear-4 =b4.fyear
	left join comp6 b5   on a.gvkey=b5.gvkey   and a.fyear-5 =b5.fyear
	left join comp6 b6   on a.gvkey=b6.gvkey   and a.fyear-6 =b6.fyear
	left join comp6 b7   on a.gvkey=b7.gvkey   and a.fyear-7 =b7.fyear
	left join comp6 b8   on a.gvkey=b8.gvkey   and a.fyear-8 =b8.fyear
	left join comp6 b9   on a.gvkey=b9.gvkey   and a.fyear-9 =b9.fyear
	left join comp6 b10  on a.gvkey=b10.gvkey  and a.fyear-10=b10.fyear; 
	quit;

data comp8;
	set comp7;

	/*rda_5yr is the amortization of R&D capital assuming a 5-year useful life. Other variables are defined similarly.*/
	rda_5yr =(1/5) *sum(of rd_lag1-rd_lag5,0);
	rda_7yr =(1/7) *sum(of rd_lag1-rd_lag7,0);
	rda_10yr=(1/10)*sum(of rd_lag1-rd_lag10,0);

	ada_2yr =(1/2) *sum(of ad_lag1-ad_lag2,0);
	ada_5yr =(1/5) *sum(of ad_lag1-ad_lag5,0);

	sga_a_5yr =(1/5) *sum(of inv_sga_lag1-inv_sga_lag5,0);

	rda=rda_5yr;
	ada=ada_2yr;

	/*rd_asset is R&D capital using a 5-year useful life. Other variables are defined similarly*/
	    rd_asset=sum(rd,4/5*rd_lag1,3/5*rd_lag2,2/5*rd_lag3,1/5*rd_lag4,0);
	lag_rd_asset=sum(       rd_lag1,4/5*rd_lag2,3/5*rd_lag3,2/5*rd_lag4,1/5*rd_lag5,0);
	    ad_asset=sum(ad,1/2*ad_lag1,0);
	lag_ad_asset=sum(       ad_lag1,1/2*ad_lag2,0);
	    sga_asset=sum(inv_sga,4/5*inv_sga_lag1,3/5*inv_sga_lag2,2/5*inv_sga_lag3,1/5*inv_sga_lag4,0);
	lag_sga_asset=sum(            inv_sga_lag1,4/5*inv_sga_lag2,3/5*inv_sga_lag3,2/5*inv_sga_lag4,1/5*inv_sga_lag5,0);

	intangible=rd+ad;
	alt_intangible=rd+ad+inv_sga;

	intangible_amortization=rda+ada;
	alt_intangible_amortization=rda+ada+sga_a_5yr;

	/*modified ACC and CFO*/
	mod_acc=acc-intangible_amortization;
	mod_cfo=cfo+intangible;

	/*modified BE and alt modified BE*/
	ave_ceq_rd=((ceq+rd_asset+ad_asset          )+(lag_ceq+lag_rd_asset+lag_ad_asset              ))/2;
	ave_ceq_es=((ceq+rd_asset+ad_asset+sga_asset)+(lag_ceq+lag_rd_asset+lag_ad_asset+lag_sga_asset))/2;

	/*Alt modified ACC and CFO*/
	es_acc=acc-alt_intangible_amortization;
	es_cfo=cfo+alt_intangible;

	/*Additional modified ACC for robustness tests*/
	adj_10yr_5yr_acc=acc -rda_10yr -ada_5yr;
	adj_10yr_2yr_acc=acc -rda_10yr -ada_2yr;
	adj_7yr_5yr_acc =acc -rda_7yr  -ada_5yr;
	adj_7yr_2yr_acc =acc -rda_7yr  -ada_2yr;
	adj_5yr_5yr_acc =acc -rda_5yr  -ada_5yr;

	/*Other variables*/
	if ib<0 then loss=1; else loss=0;
	si=abs(OIADP-pi)/ave_at;
	if missing(si) then si=0;
	lev=lt/at;
	inverse_at  = 1/ave_at;
	inverse_mve = 1/ave_mve;

	/*Scaled variables*/
	acc_ave_ceq    = 	 acc/ave_ceq;
	cfo_ave_ceq    = 	 cfo/ave_ceq;

		acc_ave_at = 	 acc/ave_at;
		cfo_ave_at = 	 cfo/ave_at;
	mod_acc_ave_at = mod_acc/ave_at;
	mod_cfo_ave_at = mod_cfo/ave_at;

		acc_ave_mve = 	  acc/ave_mve;
		cfo_ave_mve = 	  cfo/ave_mve;
	mod_acc_ave_mve = mod_acc/ave_mve;
	mod_cfo_ave_mve = mod_cfo/ave_mve;

	intangible_amortization_ave_at = intangible_amortization/ave_at;
	intangible_ave_at = intangible/ave_at;
	capx_ave_at = capx/ave_at;

	intangible_amortization_ave_mve = intangible_amortization/ave_mve;
	intangible_ave_mve = intangible/ave_mve;
 
		acc_beg_mve=	acc/lag_mve; 
		cfo_beg_mve=	cfo/lag_mve; 
	mod_acc_beg_mve=mod_acc/lag_mve; 
	mod_cfo_beg_mve=mod_cfo/lag_mve; 

		acc_end_mve=	acc/mve; 
		cfo_end_mve=	cfo/mve; 
	mod_acc_end_mve=mod_acc/mve; 
	mod_cfo_end_mve=mod_cfo/mve; 

	es_cfo_ave_at  = es_cfo/ave_at;
	es_acc_ave_at  = es_acc/ave_at;

	es_cfo_ave_mve = es_cfo/ave_mve;
	es_acc_ave_mve = es_acc/ave_mve;

	adj_10yr_2yr_acc_ave_mve = adj_10yr_2yr_acc/ave_mve;
	adj_10yr_5yr_acc_ave_mve = adj_10yr_5yr_acc/ave_mve;
	adj_7yr_5yr_acc_ave_mve  = adj_7yr_5yr_acc/ave_mve;
	adj_7yr_2yr_acc_ave_mve  = adj_7yr_2yr_acc/ave_mve;
	adj_5yr_5yr_acc_ave_mve  = adj_5yr_5yr_acc/ave_mve;

	mod_acc_ave_ceq    = mod_acc/ave_ceq;
	mod_cfo_ave_ceq    = mod_cfo/ave_ceq;
		acc_ave_ceq_rd = 	 acc/ave_ceq_rd;
		cfo_ave_ceq_rd = 	 cfo/ave_ceq_rd;
	mod_acc_ave_ceq_rd = mod_acc/ave_ceq_rd;
	mod_cfo_ave_ceq_rd = mod_cfo/ave_ceq_rd;
		acc_ave_ceq_es = 	 acc/ave_ceq_es;
		cfo_ave_ceq_es = 	 cfo/ave_ceq_es;
	mod_acc_ave_ceq_es = mod_acc/ave_ceq_es;
	mod_cfo_ave_ceq_es = mod_cfo/ave_ceq_es;
	 es_acc_ave_ceq_es =  es_acc/ave_ceq_es;
	 es_cfo_ave_ceq_es =  es_cfo/ave_ceq_es;

	/*Alternative definition of ACC and CFO following Chen et al. (2020)*/
	omission_error=-sum(txdc,esubc,fopo,SPPIV,0);
		oacc = (ch_act-ch_che) - (ch_lct-ch_dlc) - dp + omission_error;
		ocfo = ib - oacc ;
	mod_oacc = oacc - intangible_amortization;
	mod_ocfo = ocfo + intangible;
	es_oacc  = oacc - alt_intangible_amortization;
 	es_ocfo  = ocfo + alt_intangible;

      	oacc_ave_at  = 	   oacc/ave_at; 
		ocfo_ave_at  = 	   ocfo/ave_at;
	mod_oacc_ave_at  = mod_oacc/ave_at;
	mod_ocfo_ave_at  = mod_ocfo/ave_at;

      	oacc_ave_mve =     oacc/ave_mve; 
		ocfo_ave_mve =     ocfo/ave_mve;
	mod_oacc_ave_mve = mod_oacc/ave_mve;
	mod_ocfo_ave_mve = mod_ocfo/ave_mve;

 	es_oacc_ave_mve    = es_oacc/ave_mve;
 	es_ocfo_ave_mve    = es_ocfo/ave_mve;

 	   oacc_ave_ceq     =    oacc/ave_ceq;
 	   ocfo_ave_ceq     =    ocfo/ave_ceq;
   mod_ocfo_ave_ceq_es  =mod_ocfo/ave_ceq_es;
 	es_ocfo_ave_ceq_es  = es_ocfo/ave_ceq_es;

	time=(fyear-1964)/100;
	run;


/*Lag and lead CFO for Dechow and Dichev model*/
proc sql;
	create table comp9 
	as select a.*
	, b.cfo_ave_at  as lag_cfo_ave_at  , b.mod_cfo_ave_at  as lag_mod_cfo_ave_at 
	, b.cfo_ave_ceq as lag_cfo_ave_ceq 
	, b.cfo_ave_mve as lag_cfo_ave_mve , b.mod_cfo_ave_mve as lag_mod_cfo_ave_mve
	from comp8 a left join comp8 b 
	on a.gvkey=b.gvkey and a.fyear-1=b.fyear;
	quit;

proc sql;
	create table comp10 
	as select a.*
	, b.cfo_ave_at  as lead_cfo_ave_at , b.mod_cfo_ave_at  as lead_mod_cfo_ave_at 	
	, b.cfo_ave_ceq as lead_cfo_ave_ceq
	, b.cfo_ave_mve as lead_cfo_ave_mve, b.mod_cfo_ave_mve as lead_mod_cfo_ave_mve
	from comp9 a left join comp9 b 
	on a.gvkey=b.gvkey and a.fyear+1=b.fyear; 
	quit;

/*Limit the sample to 1964-2019*/
data comp11;
	set comp10;
	where 1964<=fyear<=2019;
	run;

/*Winsorize continuous variables*/
%let winsor_var=
acc acc_ave_at acc_ave_ceq acc_ave_ceq_es acc_ave_ceq_rd acc_ave_mve acc_beg_mve acc_end_mve adj_10yr_2yr_acc_ave_mve 
adj_10yr_5yr_acc_ave_mve adj_5yr_5yr_acc_ave_mve adj_7yr_2yr_acc_ave_mve adj_7yr_5yr_acc_ave_mve intangible_amortization intangible_amortization_ave_at 
intangible_amortization_ave_mve ave_at ave_mve cfo cfo_ave_at cfo_ave_ceq cfo_ave_ceq_es cfo_ave_ceq_rd cfo_ave_mve cfo_beg_mve cfo_end_mve 
es_acc_ave_at es_acc_ave_mve es_cfo_ave_at es_cfo_ave_ceq_es es_cfo_ave_mve es_ocfo_ave_ceq_es es_ocfo_ave_mve inverse_at inverse_mve 
lag_cfo_ave_at lag_cfo_ave_ceq lag_cfo_ave_mve lag_mod_cfo_ave_at lag_mod_cfo_ave_mve lead_cfo_ave_at lead_cfo_ave_ceq lead_cfo_ave_mve 
lead_mod_cfo_ave_at lead_mod_cfo_ave_mve mod_acc mod_acc_ave_at mod_acc_ave_ceq_es mod_acc_ave_mve mod_acc_beg_mve mod_acc_end_mve 
mod_cfo mod_cfo_ave_at mod_cfo_ave_ceq mod_cfo_ave_ceq_es mod_cfo_ave_ceq_rd mod_cfo_ave_mve mod_cfo_beg_mve 
mod_cfo_end_mve mod_oacc_ave_at mod_oacc_ave_mve mod_ocfo_ave_at mod_ocfo_ave_ceq_es mod_ocfo_ave_mve oacc_ave_at oacc_ave_ceq oacc_ave_mve 
ocfo_ave_at ocfo_ave_ceq ocfo_ave_mve intangible intangible_ave_at intangible_ave_mve si xad xrd capx_ave_at lev;

proc sort data=comp11; 
	by fyear; 
	run;

%winsor(dsetin=comp11,  dsetout=comp12, byvar=fyear, vars= &winsor_var, type=winsor, pctl=1 99);

/*High intangible and high PTI_OP*/
proc rank data=comp12 out=comp12 ties=low groups=2; 
	var si; 
	ranks high_pti_oi; 
	run;

proc rank data=comp12 out=comp12 ties=low groups=2; 
	var intangible_ave_at; 
	ranks high_intan; 
	run;

data data.ACC_CFO; 
	set comp12(keep=&winsor_var datadate fyear gvkey loss time high_pti_oi high_intan); 
	run;

proc datasets nowarn nolist nodetails;
     delete comp6-comp12 Xtemp Xtemp_pctl;
	 run; quit;

*==================================================================;
*Variables for mispricing & risk tests;
*===================================================================;
data sample; 
	set data.ACC_CFO; 
	yyyymm=year(datadate)*100+month(datadate); 
	run;

/*Add CRSP identifiers*/
proc sql;
	create table ccm1 
	as select a.*, b.lpermno as permno
	from sample a left join crsp.ccmxpf_linktable (where=(linktype in ('LU' 'LC') 
	and LINKPRIM in ('P' 'C') and not missing(lpermno))) as b
	on a.gvkey=b.gvkey and (linkdt <= a.datadate) 
	and (a.datadate <= linkenddt or linkenddt= .E);
	quit;

/*Merge MISP*/
/*We downloaded MISP measure from http://finance.wharton.upenn.edu/~stambaug/ on May 28, 2021*/
/*The data were available until 2016*/
proc import datafile="..\Data\MISP\Misp_Score.txt" out=mis_price dbms=dlm  replace;  
	getnames=yes; 
	run;

data mis_price2 (keep=permno yyyymm misp); 
	set mis_price (keep=_ var3 var5); 
	permno=_; 
	yyyymm=var3; 
	misp=var5; 
	run;

proc sql; 
	create table sample_misp 
	as select a.*, b.misp 
	from ccm1 a left join mis_price2 b 
	on a.yyyymm=b.yyyymm and a.permno=b.permno; 
	quit;

/*Add CRSP*/
data crsp;
	set crsp.msf;
    if ret in (-44, -55, -66, -77, -88, -99) then delete;  * missing return codes;
	run;

proc sql; 
	create table crsp1
    as select a.*, sum(1,ret)*sum(1,dlret)-1 as adjret /*returns adjusted for delisting*/
	from crsp as a left join crsp.msedelist (where=(missing(dlret)=0)) as b 
	on a.permno=b.permno and intnx('month',a.date,0,'E')=intnx('day',b.DLSTDT,0,'E');
	quit;

/*Merge ccm and crsp*/
proc sql;
	create table ccm_crsp (where =(not missing(adjret)))
    as select intnx('month',date,0,'E') as date format date9., adjret, a.*
	from ccm1 as a left join crsp1 as b 
	on a.permno=b.permno and intnx('month',a.datadate,-12,'E')<b.date<=intnx('month',a.datadate,0,'E');
	quit; 

/*Risk*/
proc sql;
	create table risk (keep=permno fyear risk)
    as select *	, std(adjret) as risk
    from ccm_crsp
    group by permno, fyear
	order by permno, fyear, date;
	quit;

proc sort data=risk nodupkey; 
	by permno fyear; 
	run;

proc sql; 
	create table sample_misp_std 
	as select a.*, b.risk  
	from sample_misp as a left join risk as b 
	on a.permno=b.permno and a.fyear=b.fyear; 
	quit;

/*Alpha as a measure for mispricing*/
proc sql;
	create table ccm_crsp (where =(not missing(adjret)))
    as select intnx('month',date,0,'E') as date format date9., adjret, a.*
	from ccm1 as a left join crsp1 as b 
	on a.permno=b.permno and intnx('month',a.datadate,0,'E')<b.date<=intnx('month',a.datadate,+12,'E');
	quit; 

/*Add factors*/
proc sql;
	create table ret_ff 
    as select a.date, permno, fyear, adjret-rf as ex_ret, mktrf, smb, hml, umd
	from ccm_crsp as a left join ff.Factors_monthly as b 
	on intnx('month',a.date,0,'E')=intnx('month',b.date,0,'E');
	quit;

proc sort data=ret_ff; 
	by permno fyear;
	run;

/*Alpha using three- and four-factor models*/
proc reg noprint data=ret_ff outest=three_factor edf; 
	model ex_ret = mktrf smb hml; 
	by permno fyear; 
	run;

proc reg noprint data=ret_ff outest=four_factor edf; 
	model ex_ret = mktrf smb hml umd; 
	by permno fyear; 
 	run;

data three_factor; 
	set three_factor; 
	rename intercept=alpha3; 
	if _edf_>=6; 
	run;

data four_factor; 
	set four_factor; 
	rename intercept=alpha4; 
	if _edf_>=5; 
	run;

/*Merge Alpha*/
proc sql; 
	create table sample_mispricing_risk  
	as select a.*, b.alpha3, c.alpha4
	from sample_misp_std a 
	left join three_factor b on a.fyear=b.fyear and a.permno=b.permno
	left join  four_factor c on a.fyear=c.fyear and a.permno=c.permno; 
	quit;

/*Quartiles for mispricing and risk for each of high and low intangible subsamples*/
proc rank data=sample_mispricing_risk  
	out=High_Intan (keep=gvkey fyear r_misp r_risk r_alpha3 r_alpha4 high_intan) 
	ties=low groups=4; 
	var misp risk alpha3 alpha4; 
	by fyear; 
	ranks r_misp r_risk r_alpha3 r_alpha4; 
	where high_intan=1; 
	run;

proc rank data=sample_mispricing_risk  
	out=Low_Intan  (keep=gvkey fyear r_misp r_risk r_alpha3 r_alpha4 high_intan) 
	ties=low groups=4; 
	var misp risk alpha3 alpha4; 
	by fyear; 
	ranks r_misp r_risk r_alpha3 r_alpha4; 
	where high_intan=0; 
	run;

/*Merge quartiles for mispricing and risk proxies*/
proc datasets noprint; 
	append base = High_Intan data=Low_Intan; 
	run;

proc sql; 
	create table sample_mispricing_risk  
	as select a.*, b.r_misp, b.r_risk, b.r_alpha3, b.r_alpha4 
	from sample_mispricing_risk a left join High_Intan b 
	on a.fyear=b.fyear and a.gvkey=b.gvkey; 
	quit;

/*Proxies of mispricing and risk*/
data sample_mispricing_risk; 
	set sample_mispricing_risk;
	if r_misp in (3) then over_misp=1; else over_misp=0; 
	if r_misp in (0) then under_misp=1; else under_misp=0; 
	if r_risk in (3) then HighRisk=1; else HighRisk=0; 
	if r_risk in (0) then  LowRisk=1; else  LowRisk=0;
	if r_alpha3 in (0) then over_a3=1; else over_a3=0; 
	if r_alpha3 in (3) then under_a3=1; else under_a3=0; 
	if r_alpha4 in (0) then over_a4=1; else over_a4=0; 
	if r_alpha4 in (3) then under_a4=1; else under_a4=0; 
	run;

/*Save main Stata dataset*/
proc export data=sample_mispricing_risk outfile="..\Data\ACC_CFO.dta" DBMS=STATA replace; 
	run;


	*======================Estimate coefficient on CFO using Annual regressions=============;
proc sort data=data.ACC_CFO out=sample; 
	by fyear; 
	run;

proc reg data=sample outest=coeff_at         noprint; by fyear; model     acc_ave_at   =     cfo_ave_at  /adjrsq; run;
proc reg data=sample outest=coeff_at_mod     noprint; by fyear; model mod_acc_ave_at   = mod_cfo_ave_at  /adjrsq; run;
proc reg data=sample outest=coeff_ceq        noprint; by fyear; model     acc_ave_ceq  =     cfo_ave_ceq /adjrsq; run;
proc reg data=sample outest=coeff_mve        noprint; by fyear; model     acc_ave_mve  =     cfo_ave_mve /adjrsq; run;
proc reg data=sample outest=coeff_mve_mod    noprint; by fyear; model mod_acc_ave_mve  = mod_cfo_ave_mve /adjrsq; run;

data coeff_at      (keep=fyear      cfo_ave_at_b);  set coeff_at;          cfo_ave_at_b  =     cfo_ave_at;  run;
data coeff_at_mod  (keep=fyear  mod_cfo_ave_at_b);  set coeff_at_mod;  mod_cfo_ave_at_b  = mod_cfo_ave_at;  run;
data coeff_ceq     (keep=fyear     cfo_ave_ceq_b); set coeff_ceq;         cfo_ave_ceq_b =     cfo_ave_ceq; run;
data coeff_mve     (keep=fyear     cfo_ave_mve_b); set coeff_mve;         cfo_ave_mve_b =     cfo_ave_mve; run;
data coeff_mve_mod (keep=fyear mod_cfo_ave_mve_b); set coeff_mve_mod; mod_cfo_ave_mve_b = mod_cfo_ave_mve; run;

/*Average/STD for intangibles/capx/leverage*/
proc means data=sample noprint;
	var intangible_ave_at capx_ave_at intangible_ave_mve lev; 
	by fyear; 
	output out=mean_rd 
	mean(intangible_ave_at)=m_intangible_ave_at mean(capx_ave_at)=m_capx_ave_at 
	mean(intangible_ave_mve)=m_intangible_ave_mve 
	std(intangible_ave_at)=std_intangible_ave_at std(lev)=std_lev; 
	run;

/*Merge annual data*/
data data.annual_sample; 
	merge coeff_at coeff_at_mod coeff_ceq coeff_mve coeff_mve_mod mean_rd (drop=_type_ _freq_); 
	by fyear; 
	time=(fyear-1964)/100; 
	run;

proc export data=data.annual_sample outfile="..\Data\Annual_ACC_CFO.dta" DBMS=STATA replace; 
	run;

*==================================================================;
*Figure One;
*===================================================================;
ods graphics on / width=6.4in height=2.98in border=off imagename="fig1A" imagefmt=png ;
ods listing gpath="&FiguresAddress" ;
options nodate nonumber sysprintfont="Courier" REPLACE;
proc sgplot data=data.annual_sample ;
   reg y=cfo_ave_at_b x=fyear/markerattrs=(symbol=circle) LEGENDLABEL="Trend in the coefficient: Replication of Bushman et al. (2016)";
   reg y=mod_cfo_ave_at_b x=fyear/markerattrs=(symbol=square) LEGENDLABEL="Trend in the coefficient: Numerator adjustments"; 
   	yaxis 
	label = "Coefficient on CFO"
	values=(-2 -1.5 -1 -0.5 0 0.5)
	labelattrs=(size=15pt weight=bold)
    valueattrs=(size=16pt weight=bold);
	xaxis
	labelattrs=( size=16pt weight=bold)
    valueattrs=( size=16pt weight=bold)
	label = "Year";
	keylegend / location=inside position=BOTTOMRIGHT  across=1;
	run;
ods graphics off;

ods graphics on / width=6.4in height=2.98in border=off imagename="fig1B" imagefmt=png;
ods listing gpath="&FiguresAddress";
options nodate nonumber sysprintfont="Courier";
proc sgplot data=data.annual_sample;
   reg y=cfo_ave_at_b x=fyear/markerattrs=(symbol=circle) LEGENDLABEL="Trend in the coefficient: Replication of Bushman et al. (2016)";
   reg y=cfo_ave_ceq_b x=fyear/markerattrs=(symbol=square) LEGENDLABEL="Trend in the coefficient: Denominator adjustments (BE)";
	yaxis 
	label = "Coefficient on CFO"
	values=(-2 -1.5 -1 -0.5 0 0.5)
	labelattrs=(size=15pt weight=bold)
    valueattrs=(size=16pt weight=bold);
	xaxis
	labelattrs=( size=16pt weight=bold)
    valueattrs=( size=16pt weight=bold)
	label = "Year";
	keylegend / location=inside position=BOTTOMRIGHT  across=1;
	run;
ods graphics off;

ods graphics on / width=6.4in height=2.98in border=off imagename="fig1C" imagefmt=png;
ods listing gpath="&FiguresAddress";
options nodate nonumber sysprintfont="Courier";
proc sgplot data=data.annual_sample;
   reg y=cfo_ave_at_b x=fyear/markerattrs=(symbol=circle) LEGENDLABEL="Trend in the coefficient: Replication of Bushman et al. (2016)";
   reg y=cfo_ave_mve_b x=fyear/markerattrs=(symbol=square) LEGENDLABEL="Trend in the coefficient: Denominator adjustments (MV)";
	yaxis 
	label = "Coefficient on CFO"
	values=(-2 -1.5 -1 -0.5 0 0.5)
	labelattrs=(size=15pt weight=bold)
    valueattrs=(size=16pt weight=bold);
	xaxis
	labelattrs=( size=16pt weight=bold)
    valueattrs=( size=16pt weight=bold)
	label = "Year";
	keylegend / location=inside position=BOTTOMRIGHT  across=1;
	run;
ods graphics off;

ods graphics on / width=6.4in height=2.98in border=off imagename="fig1D" imagefmt=png;
ods listing gpath="&FiguresAddress";
options nodate nonumber sysprintfont="Courier";
proc sgplot data=data.annual_sample;
   reg y=cfo_ave_at_b x=fyear/markerattrs=(symbol=circle) LEGENDLABEL="Trend in the coefficient: Replication of Bushman et al. (2016)";
   reg y=mod_cfo_ave_mve_b x=fyear/markerattrs=(symbol=square) LEGENDLABEL="Trend in the coefficient: Numerator and denominator adjustments";
	yaxis 
	label = "Coefficient on CFO"
	values=(-2 -1.5 -1 -0.5 0 0.5)
	labelattrs=(size=15pt weight=bold)
    valueattrs=(size=16pt weight=bold);
	xaxis
	labelattrs=( size=16pt weight=bold)
    valueattrs=( size=16pt weight=bold)
	label = "Year";
	keylegend / location=inside position=BOTTOMRIGHT  across=1;
	run;
ods graphics off;

*==================================================================;
*Figure Two;
*===================================================================;
proc sort data=data.ACC_CFO out=weight (keep=fyear intangible_ave_at inverse_at inverse_mve); 
	by fyear intangible_ave_at; 
	run;

proc rank data=weight out=weight ties=low groups=10; 
	var intangible_ave_at; 
	ranks d_intangible_ave_at; 
	by fyear; 
	run;

proc means data=weight noprint; 
	var inverse_at inverse_mve; 
	by fyear d_intangible_ave_at; 
	output out=weight2 
	sum=s_inverse_at s_inverse_mve; 
	run;

proc sql;
    create table weight3
    as select *, sum(s_inverse_at)  as s_s_inverse_at, sum(s_inverse_mve) as s_s_inverse_mve
    from weight2
    group by fyear;
	quit;

/*Weights on high intangible firms*/
data weight4; 
	set weight3;
	if d_intangible_ave_at=9; 
	intan_at = (s_inverse_at /s_s_inverse_at);
	intan_mve= (s_inverse_mve/s_s_inverse_mve );
	run;

	*======================Figure two=============;
ods graphics on / width=6.4in height=2.98in border=off imagename="Fig2" imagefmt=png;
ods listing gpath="&FiguresAddress";
options nodate nonumber sysprintfont="Courier";
proc sgplot data=weight4;
   reg y=intan_at  x=fyear/markerattrs=(symbol=circle) legendlabel="Deflator: Asset";
   reg y=intan_mve x=fyear/markerattrs=(symbol=square) legendlabel="Deflator: MV";
	yaxis 
	label = "Weights on High Intangible Firms"
	labelattrs=(size=15pt weight=bold)
    valueattrs=(size=16pt weight=bold);
	xaxis
	labelattrs=( size=16pt weight=bold)
    valueattrs=( size=16pt weight=bold)
	label = "Year";
	keylegend / location=inside position=BOTTOMRIGHT  across=1;
	run;
ods graphics off;
